@@ -21,16 +21,14 @@ from typing import (
 )
 
 import yaml
-from dagster_airbyte.resources import AirbyteResource
-from dagster_airbyte.types import AirbyteTableMetadata
-from dagster_airbyte.utils import (
-    generate_materializations,
-    generate_table_schema,
-    is_basic_normalization_operation,
+from dagster import (
+    AssetKey,
+    AssetOut,
+    FreshnessPolicy,
+    Output,
+    ResourceDefinition,
+    _check as check,
 )
-
-from dagster import AssetKey, AssetOut, Output, ResourceDefinition
-from dagster import _check as check
 from dagster._annotations import experimental
 from dagster._core.definitions import AssetsDefinition, multi_asset
 from dagster._core.definitions.cacheable_assets import (
@@ -41,7 +39,15 @@ from dagster._core.definitions.events import CoercibleToAssetKeyPrefix
 from dagster._core.definitions.metadata import MetadataValue, TableSchemaMetadataValue
 from dagster._core.definitions.metadata.table import TableSchema
 from dagster._core.execution.context.init import build_init_resource_context
-from dagster._utils import merge_dicts
+from dagster._utils.merger import merge_dicts
+
+from dagster_airbyte.resources import AirbyteResource
+from dagster_airbyte.types import AirbyteTableMetadata
+from dagster_airbyte.utils import (
+    generate_materializations,
+    generate_table_schema,
+    is_basic_normalization_operation,
+)
 
 
 def _build_airbyte_asset_defn_metadata(
@@ -54,8 +60,8 @@ def _build_airbyte_asset_defn_metadata(
     group_name: Optional[str] = None,
     io_manager_key: Optional[str] = None,
     schema_by_table_name: Optional[Mapping[str, TableSchema]] = None,
+    freshness_policy: Optional[FreshnessPolicy] = None,
 ) -> AssetsDefinitionCacheableData:
-
     asset_key_prefix = (
         check.opt_sequence_param(asset_key_prefix, "asset_key_prefix", of_type=str) or []
     )
@@ -114,6 +120,7 @@ def _build_airbyte_asset_defn_metadata(
             "destination_tables": destination_tables,
             "normalization_tables": normalization_tables,
             "io_manager_key": io_manager_key,
+            "freshness_policy": freshness_policy,
         },
     )
 
@@ -122,13 +129,13 @@ def _build_airbyte_assets_from_metadata(
     assets_defn_meta: AssetsDefinitionCacheableData,
     resource_defs: Optional[Mapping[str, ResourceDefinition]],
 ) -> AssetsDefinition:
-
     metadata = cast(Mapping[str, Any], assets_defn_meta.extra_metadata)
     connection_id = cast(str, metadata["connection_id"])
     group_name = cast(Optional[str], metadata["group_name"])
     destination_tables = cast(List[str], metadata["destination_tables"])
     normalization_tables = cast(Mapping[str, List[str]], metadata["normalization_tables"])
     io_manager_key = cast(Optional[str], metadata["io_manager_key"])
+    freshness_policy = cast(Optional[FreshnessPolicy], metadata["freshness_policy"])
 
     @multi_asset(
         name=f"airbyte_sync_{connection_id[:5]}",
@@ -143,6 +150,7 @@ def _build_airbyte_assets_from_metadata(
                 if assets_defn_meta.metadata_by_output_name
                 else None,
                 io_manager_key=io_manager_key,
+                freshness_policy=freshness_policy,
             )
             for k, v in (assets_defn_meta.keys_by_output_name or {}).items()
         },
@@ -190,6 +198,7 @@ def build_airbyte_assets(
     normalization_tables: Optional[Mapping[str, Set[str]]] = None,
     upstream_assets: Optional[Set[AssetKey]] = None,
     schema_by_table_name: Optional[Mapping[str, TableSchema]] = None,
+    freshness_policy: Optional[FreshnessPolicy] = None,
 ) -> Sequence[AssetsDefinition]:
     """
     Builds a set of assets representing the tables created by an Airbyte sync operation.
@@ -206,8 +215,8 @@ def build_airbyte_assets(
         asset_key_prefix (Optional[List[str]]): A prefix for the asset keys inside this asset.
             If left blank, assets will have a key of `AssetKey([table_name])`.
         upstream_assets (Optional[Set[AssetKey]]): A list of assets to add as sources.
+        freshness_policy (Optional[FreshnessPolicy]): A freshness policy to apply to the assets
     """
-
     asset_key_prefix = check.opt_sequence_param(asset_key_prefix, "asset_key_prefix", of_type=str)
 
     # Generate a list of outputs, the set of destination tables plus any affiliated
@@ -221,6 +230,7 @@ def build_airbyte_assets(
             metadata={"table_schema": MetadataValue.table_schema(schema_by_table_name[table])}
             if schema_by_table_name
             else None,
+            freshness_policy=freshness_policy,
         )
         for table in tables
     }
@@ -304,7 +314,6 @@ def _get_normalization_tables_for_schema(
     For more information on Airbyte's normalization process, see:
     https://docs.airbyte.com/understanding-airbyte/basic-normalization/#nesting
     """
-
     out: Dict[str, AirbyteTableMetadata] = {}
     # Object types are broken into a new table, as long as they have children
 
@@ -404,7 +413,6 @@ class AirbyteConnectionMetadata(
         tables associated with each enabled stream and values representing any affiliated
         tables created by Airbyte's normalization process, if enabled.
         """
-
         tables: Dict[str, AirbyteTableMetadata] = {}
 
         enabled_streams = [
@@ -440,7 +448,6 @@ class AirbyteConnectionMetadata(
 def _get_schema_by_table_name(
     stream_table_metadata: Mapping[str, AirbyteTableMetadata]
 ) -> Mapping[str, TableSchema]:
-
     schema_by_base_table_name = [(k, v.schema) for k, v in stream_table_metadata.items()]
     schema_by_normalization_table_name = list(
         chain.from_iterable(
@@ -468,8 +475,10 @@ class AirbyteCoreCacheableAssetsDefinition(CacheableAssetsDefinition):
         connection_to_io_manager_key_fn: Optional[Callable[[str], Optional[str]]],
         connection_filter: Optional[Callable[[AirbyteConnectionMetadata], bool]],
         connection_to_asset_key_fn: Optional[Callable[[AirbyteConnectionMetadata, str], AssetKey]],
+        connection_to_freshness_policy_fn: Optional[
+            Callable[[AirbyteConnectionMetadata], Optional[FreshnessPolicy]]
+        ],
     ):
-
         self._key_prefix = key_prefix
         self._create_assets_for_normalization_tables = create_assets_for_normalization_tables
         self._connection_to_group_fn = connection_to_group_fn
@@ -478,6 +487,9 @@ class AirbyteCoreCacheableAssetsDefinition(CacheableAssetsDefinition):
         self._connection_to_asset_key_fn: Callable[
             [AirbyteConnectionMetadata, str], AssetKey
         ] = connection_to_asset_key_fn or (lambda _, table: AssetKey(path=[table]))
+        self._connection_to_freshness_policy_fn = connection_to_freshness_policy_fn or (
+            lambda _: None
+        )
 
         contents = hashlib.sha1()  # so that hexdigest is 40, not 64 bytes
         contents.update(",".join(key_prefix).encode("utf-8"))
@@ -492,10 +504,8 @@ class AirbyteCoreCacheableAssetsDefinition(CacheableAssetsDefinition):
         pass
 
     def compute_cacheable_data(self) -> Sequence[AssetsDefinitionCacheableData]:
-
         asset_defn_data: List[AssetsDefinitionCacheableData] = []
-        for (connection_id, connection) in self._get_connections():
-
+        for connection_id, connection in self._get_connections():
             stream_table_metadata = connection.parse_stream_tables(
                 self._create_assets_for_normalization_tables
             )
@@ -518,6 +528,7 @@ class AirbyteCoreCacheableAssetsDefinition(CacheableAssetsDefinition):
                 else None,
                 schema_by_table_name=schema_by_table_name,
                 table_to_asset_key_fn=table_to_asset_key,
+                freshness_policy=self._connection_to_freshness_policy_fn(connection),
             )
 
             asset_defn_data.append(asset_data_for_conn)
@@ -548,6 +559,9 @@ class AirbyteInstanceCacheableAssetsDefinition(AirbyteCoreCacheableAssetsDefinit
         connection_to_io_manager_key_fn: Optional[Callable[[str], Optional[str]]],
         connection_filter: Optional[Callable[[AirbyteConnectionMetadata], bool]],
         connection_to_asset_key_fn: Optional[Callable[[AirbyteConnectionMetadata, str], AssetKey]],
+        connection_to_freshness_policy_fn: Optional[
+            Callable[[AirbyteConnectionMetadata], Optional[FreshnessPolicy]]
+        ],
     ):
         super().__init__(
             key_prefix=key_prefix,
@@ -556,6 +570,7 @@ class AirbyteInstanceCacheableAssetsDefinition(AirbyteCoreCacheableAssetsDefinit
             connection_to_io_manager_key_fn=connection_to_io_manager_key_fn,
             connection_filter=connection_filter,
             connection_to_asset_key_fn=connection_to_asset_key_fn,
+            connection_to_freshness_policy_fn=connection_to_freshness_policy_fn,
         )
         self._workspace_id = workspace_id
         self._airbyte_resource_def = airbyte_resource_def
@@ -629,6 +644,9 @@ class AirbyteYAMLCacheableAssetsDefinition(AirbyteCoreCacheableAssetsDefinition)
         connection_filter: Optional[Callable[[AirbyteConnectionMetadata], bool]],
         connection_directories: Optional[Sequence[str]],
         connection_to_asset_key_fn: Optional[Callable[[AirbyteConnectionMetadata, str], AssetKey]],
+        connection_to_freshness_policy_fn: Optional[
+            Callable[[AirbyteConnectionMetadata], Optional[FreshnessPolicy]]
+        ],
     ):
         super().__init__(
             key_prefix=key_prefix,
@@ -637,6 +655,7 @@ class AirbyteYAMLCacheableAssetsDefinition(AirbyteCoreCacheableAssetsDefinition)
             connection_to_io_manager_key_fn=connection_to_io_manager_key_fn,
             connection_filter=connection_filter,
             connection_to_asset_key_fn=connection_to_asset_key_fn,
+            connection_to_freshness_policy_fn=connection_to_freshness_policy_fn,
         )
         self._workspace_id = workspace_id
         self._project_dir = project_dir
@@ -649,7 +668,6 @@ class AirbyteYAMLCacheableAssetsDefinition(AirbyteCoreCacheableAssetsDefinition)
 
         connection_directories = self._connection_directories or os.listdir(connections_dir)
         for connection_name in connection_directories:
-
             connection_dir = os.path.join(connections_dir, connection_name)
             with open(os.path.join(connection_dir, "configuration.yaml"), encoding="utf-8") as f:
                 connection = AirbyteConnectionMetadata.from_config(yaml.safe_load(f.read()))
@@ -678,9 +696,8 @@ class AirbyteYAMLCacheableAssetsDefinition(AirbyteCoreCacheableAssetsDefinition)
                 )
                 check.invariant(
                     len(state_files) <= 1,
-                    "More than one state file found for connection {} in {}, specify a workspace_id to disambiguate".format(
-                        connection_name, connection_dir
-                    ),
+                    "More than one state file found for connection {} in {}, specify a workspace_id"
+                    " to disambiguate".format(connection_name, connection_dir),
                 )
                 state_file = state_files[0]
 
@@ -705,6 +722,9 @@ def load_assets_from_airbyte_instance(
     connection_to_asset_key_fn: Optional[
         Callable[[AirbyteConnectionMetadata, str], AssetKey]
     ] = None,
+    connection_to_freshness_policy_fn: Optional[
+        Callable[[AirbyteConnectionMetadata], Optional[FreshnessPolicy]]
+    ] = None,
 ) -> CacheableAssetsDefinition:
     """
     Loads Airbyte connection assets from a configured AirbyteResource instance. This fetches information
@@ -733,6 +753,9 @@ def load_assets_from_airbyte_instance(
         connection_to_asset_key_fn (Optional[Callable[[AirbyteConnectionMetadata, str], AssetKey]]): Optional function which
             takes in connection metadata and table name and returns an asset key for the table. If None, the default asset
             key is based on the table name. Any asset key prefix will be applied to the output of this function.
+        connection_to_freshness_policy_fn (Optional[Callable[[AirbyteConnectionMetadata], Optional[FreshnessPolicy]]]): Optional function
+            which takes in connection metadata and returns a freshness policy for the connection's assets. If None, no freshness policies
+            will be applied to the assets.
 
     **Examples:**
 
@@ -767,7 +790,6 @@ def load_assets_from_airbyte_instance(
             connection_filter=lambda meta: "snowflake" in meta.name,
         )
     """
-
     if isinstance(key_prefix, str):
         key_prefix = [key_prefix]
     key_prefix = check.list_param(key_prefix or [], "key_prefix", of_type=str)
@@ -788,6 +810,7 @@ def load_assets_from_airbyte_instance(
         connection_to_io_manager_key_fn=connection_to_io_manager_key_fn,
         connection_filter=connection_filter,
         connection_to_asset_key_fn=connection_to_asset_key_fn,
+        connection_to_freshness_policy_fn=connection_to_freshness_policy_fn,
     )
 
 
@@ -805,6 +828,9 @@ def load_assets_from_airbyte_project(
     connection_to_asset_key_fn: Optional[
         Callable[[AirbyteConnectionMetadata, str], AssetKey]
     ] = None,
+    connection_to_freshness_policy_fn: Optional[
+        Callable[[AirbyteConnectionMetadata], Optional[FreshnessPolicy]]
+    ] = None,
 ) -> CacheableAssetsDefinition:
     """
     Loads an Airbyte project into a set of Dagster assets.
@@ -837,6 +863,9 @@ def load_assets_from_airbyte_project(
         connection_to_asset_key_fn (Optional[Callable[[AirbyteConnectionMetadata, str], AssetKey]]): Optional function which
             takes in connection metadata and table name and returns an asset key for the table. If None, the default asset
             key is based on the table name. Any asset key prefix will be applied to the output of this function.
+        connection_to_freshness_policy_fn (Optional[Callable[[AirbyteConnectionMetadata], Optional[FreshnessPolicy]]]):
+            Optional function which takes in connection metadata and returns a freshness policy for the connection's assets.
+            If None, no freshness policies will be applied to the assets.
 
     **Examples:**
 
@@ -861,7 +890,6 @@ def load_assets_from_airbyte_project(
             connection_filter=lambda meta: "snowflake" in meta.name,
         )
     """
-
     if isinstance(key_prefix, str):
         key_prefix = [key_prefix]
     key_prefix = check.list_param(key_prefix or [], "key_prefix", of_type=str)
@@ -883,4 +911,5 @@ def load_assets_from_airbyte_project(
         connection_filter=connection_filter,
         connection_directories=connection_directories,
         connection_to_asset_key_fn=connection_to_asset_key_fn,
+        connection_to_freshness_policy_fn=connection_to_freshness_policy_fn,
     )
