@@ -1,26 +1,30 @@
+from dagster import Array, Bool, Field, In, Noneable, Nothing, Out, Output, op
+
 from dagster_airbyte.resources import DEFAULT_POLL_INTERVAL_SECONDS
 from dagster_airbyte.types import AirbyteOutput
 from dagster_airbyte.utils import _get_attempt, generate_materializations
 
-from dagster import Array, Bool, Field, In, Noneable, Nothing, Out, Output, op
-
 
 @op(
     required_resource_keys={"airbyte"},
     ins={"start_after": In(Nothing)},
     out=Out(
         AirbyteOutput,
-        description="Parsed json dictionary representing the details of the Airbyte connector after "
-        "the sync successfully completes. "
-        "See the [Airbyte API Docs](https://airbyte-public-api-docs.s3.us-east-2.amazonaws.com/rapidoc-api-docs.html#overview) "
-        "to see detailed information on this response.",
+        description=(
+            "Parsed json dictionary representing the details of the Airbyte connector after the"
+            " sync successfully completes. See the [Airbyte API"
+            " Docs](https://airbyte-public-api-docs.s3.us-east-2.amazonaws.com/rapidoc-api-docs.html#overview)"
+            " to see detailed information on this response."
+        ),
     ),
     config_schema={
         "connection_id": Field(
             str,
             is_required=True,
-            description="The Airbyte Connection ID that this op will sync. You can retrieve this "
-            'value from the "Connections" tab of a given connector in the Airbyte UI.',
+            description=(
+                "The Airbyte Connection ID that this op will sync. You can retrieve this "
+                'value from the "Connections" tab of a given connector in the Airbyte UI.'
+            ),
         ),
         "poll_interval": Field(
             float,
@@ -30,8 +34,10 @@ from dagster import Array, Bool, Field, In, Noneable, Nothing, Out, Output, op
         "poll_timeout": Field(
             Noneable(float),
             default_value=None,
-            description="The maximum time that will waited before this operation is timed out. By "
-            "default, this will never time out.",
+            description=(
+                "The maximum time that will waited before this operation is timed out. By "
+                "default, this will never time out."
+            ),
         ),
         "yield_materializations": Field(
             config=Bool,
@@ -62,31 +68,29 @@ def airbyte_sync_op(context):
     communicate with the Airbyte API.
 
     Examples:
+        .. code-block:: python
 
-    .. code-block:: python
+            from dagster import job
+            from dagster_airbyte import airbyte_resource, airbyte_sync_op
 
-        from dagster import job
-        from dagster_airbyte import airbyte_resource, airbyte_sync_op
+            my_airbyte_resource = airbyte_resource.configured(
+                {
+                    "host": {"env": "AIRBYTE_HOST"},
+                    "port": {"env": "AIRBYTE_PORT"},
+                }
+            )
 
-        my_airbyte_resource = airbyte_resource.configured(
-            {
-                "host": {"env": "AIRBYTE_HOST"},
-                "port": {"env": "AIRBYTE_PORT"},
-            }
-        )
+            sync_foobar = airbyte_sync_op.configured({"connection_id": "foobar"}, name="sync_foobar")
 
-        sync_foobar = airbyte_sync_op.configured({"connection_id": "foobar"}, name="sync_foobar")
+            @job(resource_defs={"airbyte": my_airbyte_resource})
+            def my_simple_airbyte_job():
+                sync_foobar()
 
-        @job(resource_defs={"airbyte": my_airbyte_resource})
-        def my_simple_airbyte_job():
-            sync_foobar()
-
-        @job(resource_defs={"airbyte": my_airbyte_resource})
-        def my_composed_airbyte_job():
-            final_foobar_state = sync_foobar(start_after=some_op())
-            other_op(final_foobar_state)
+            @job(resource_defs={"airbyte": my_airbyte_resource})
+            def my_composed_airbyte_job():
+                final_foobar_state = sync_foobar(start_after=some_op())
+                other_op(final_foobar_state)
     """
-
     airbyte_output = context.resources.airbyte.sync_and_poll(
         connection_id=context.op_config["connection_id"],
         poll_interval=context.op_config["poll_interval"],
